==> mx-codecs_19.4.1.tar.xz: mx-codecs-19.4.1/translations/mx-codecs_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>Morate pokrenuti ovaj program kao root.</translation>
    </message>
</context>
<context>
    <name>mxcodecs</name>
    <message>
        <location filename="../mxcodecs.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>Instalacijski program MX kodeka</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>Preuzimanje datoteka kodeka</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>Otkaži promjene i izađi</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="97"/>
        <location filename="../mxcodecs.cpp" line="256"/>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="105"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="118"/>
        <source>Apply any changes then quit</source>
        <translation>Primjeni promjene i izađi</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="121"/>
        <source>OK</source>
        <translation>U redu</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="177"/>
        <source>About this application</source>
        <translation>O ovoj aplikaciji</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="180"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="188"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="217"/>
        <source>Display help </source>
        <translation>Prikaži pomoć</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="220"/>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="228"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="113"/>
        <location filename="../mxcodecs.cpp" line="120"/>
        <location filename="../mxcodecs.cpp" line="128"/>
        <location filename="../mxcodecs.cpp" line="135"/>
        <location filename="../mxcodecs.cpp" line="143"/>
        <location filename="../mxcodecs.cpp" line="150"/>
        <location filename="../mxcodecs.cpp" line="159"/>
        <location filename="../mxcodecs.cpp" line="166"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Pokrećem naredbu...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="116"/>
        <location filename="../mxcodecs.cpp" line="131"/>
        <location filename="../mxcodecs.cpp" line="137"/>
        <location filename="../mxcodecs.cpp" line="146"/>
        <location filename="../mxcodecs.cpp" line="152"/>
        <location filename="../mxcodecs.cpp" line="162"/>
        <location filename="../mxcodecs.cpp" line="168"/>
        <location filename="../mxcodecs.cpp" line="197"/>
        <location filename="../mxcodecs.cpp" line="233"/>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="117"/>
        <location filename="../mxcodecs.cpp" line="132"/>
        <location filename="../mxcodecs.cpp" line="147"/>
        <location filename="../mxcodecs.cpp" line="163"/>
        <source>Cannot connect to the download site</source>
        <translation>Ne mogu se spojiti na stranicu preuzimanja</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="123"/>
        <location filename="../mxcodecs.cpp" line="138"/>
        <location filename="../mxcodecs.cpp" line="153"/>
        <location filename="../mxcodecs.cpp" line="169"/>
        <source>Error downloading %1</source>
        <translation>Greška pri preuzimanju %1</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="174"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Preuzimanje završeno.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="193"/>
        <source>Installing downloaded files</source>
        <translation>Instaliram preuzete datoteke</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="198"/>
        <source>No downloaded *.debs files found.</source>
        <translation>Nisu pronađene preuzete *.debs datoteke.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="211"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Instaliram...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="215"/>
        <source>Error installing %1</source>
        <translation>Greška pri instaliranju %1</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="226"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;Instalacijski proces je završen&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="229"/>
        <source>Finished</source>
        <translation>Završeno</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="230"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>Datoteke kodeka su uspješno preuzete i instalirane.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="234"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Proces je završen. Došlo je do grešaka tijekom instalacije.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="249"/>
        <source>About MX Codecs</source>
        <translation>O MX kodecima</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="250"/>
        <source>MX Codecs</source>
        <translation>MX kodeci</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="250"/>
        <source>Version: </source>
        <translation>Inačica:</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="252"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>Jednostavni preuzimatelj kodeka za MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="253"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Autorska prava (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="254"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="255"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="271"/>
        <source>&amp;Close</source>
        <translation>&amp;Zatvori</translation>
    </message>
</context>
</TS>

==> mx-codecs_19.7.1.tar.xz: mx-codecs-19.7.1/translations/mx-codecs_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Unable to get exclusive lock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You must run this program as root.</source>
        <translation>Morate pokrenuti ovaj program kao root.</translation>
    </message>
</context>
<context>
    <name>mxcodecs</name>
    <message>
        <location filename="../mxcodecs.ui" line="14"/>
        <source>MX Codecs Installer</source>
        <translation>Instalacijski program MX kodeka</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="27"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="44"/>
        <source>Downloading codecs files</source>
        <translation>Preuzimanje datoteka kodeka</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="94"/>
        <source>Cancel any changes then quit</source>
        <translation>Otkaži promjene i izađi</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="97"/>
        <location filename="../mxcodecs.cpp" line="270"/>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="105"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="118"/>
        <source>Apply any changes then quit</source>
        <translation>Primjeni promjene i izađi</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="121"/>
        <source>OK</source>
        <translation>U redu</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="177"/>
        <source>About this application</source>
        <translation>O ovoj aplikaciji</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="180"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="188"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="217"/>
        <source>Display help </source>
        <translation>Prikaži pomoć</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="220"/>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <location filename="../mxcodecs.ui" line="228"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="103"/>
        <location filename="../mxcodecs.cpp" line="110"/>
        <location filename="../mxcodecs.cpp" line="118"/>
        <location filename="../mxcodecs.cpp" line="126"/>
        <location filename="../mxcodecs.cpp" line="135"/>
        <location filename="../mxcodecs.cpp" line="142"/>
        <location filename="../mxcodecs.cpp" line="151"/>
        <location filename="../mxcodecs.cpp" line="159"/>
        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Pokrećem naredbu...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="106"/>
        <location filename="../mxcodecs.cpp" line="122"/>
        <location filename="../mxcodecs.cpp" line="129"/>
        <location filename="../mxcodecs.cpp" line="138"/>
        <location filename="../mxcodecs.cpp" line="144"/>
        <location filename="../mxcodecs.cpp" line="155"/>
        <location filename="../mxcodecs.cpp" line="162"/>
        <location filename="../mxcodecs.cpp" line="194"/>
        <location filename="../mxcodecs.cpp" line="247"/>
        <source>Error</source>
        <translation>Greška</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="107"/>
        <location filename="../mxcodecs.cpp" line="123"/>
        <location filename="../mxcodecs.cpp" line="139"/>
        <location filename="../mxcodecs.cpp" line="156"/>
        <source>Cannot connect to the download site</source>
        <translation>Ne mogu se spojiti na stranicu preuzimanja</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="113"/>
        <location filename="../mxcodecs.cpp" line="130"/>
        <location filename="../mxcodecs.cpp" line="145"/>
        <location filename="../mxcodecs.cpp" line="163"/>
        <source>Error downloading %1</source>
        <translation>Greška pri preuzimanju %1</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="168"/>
        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Preuzimanje završeno.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="190"/>
        <source>Installing downloaded files</source>
        <translation>Instaliram preuzete datoteke</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="195"/>
        <source>No downloaded *.debs files found.</source>
        <translation>Nisu pronađene preuzete *.debs datoteke.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="208"/>
        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
        <translation>&lt;b&gt;Instaliram...&lt;/b&gt;&lt;p&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="222"/>
        <source>Error installing %1</source>
        <translation>Greška pri instaliranju %1</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="226"/>
        <source>Fix missing dependencies...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="228"/>
        <source>Error running &apos;apt-get -fm install&apos; command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="240"/>
        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
        <translation>&lt;b&gt;Instalacijski proces je završen&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="243"/>
        <source>Finished</source>
        <translation>Završeno</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="244"/>
        <source>Codecs files have been downloaded and installed successfully.</source>
        <translation>Datoteke kodeka su uspješno preuzete i instalirane.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="248"/>
        <source>Process finished. Errors have occurred during the installation.</source>
        <translation>Proces je završen. Došlo je do grešaka tijekom instalacije.</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="263"/>
        <source>About MX Codecs</source>
        <translation>O MX kodecima</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="264"/>
        <source>MX Codecs</source>
        <translation>MX kodeci</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="264"/>
        <source>Version: </source>
        <translation>Inačica:</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="266"/>
        <source>Simple codecs downloader for MX Linux</source>
        <translation>Jednostavni preuzimatelj kodeka za MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="267"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Autorska prava (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="268"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="269"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxcodecs.cpp" line="285"/>
        <source>&amp;Close</source>
        <translation>&amp;Zatvori</translation>
    </message>
</context>
</TS>
